@@ -2,7 +2,7 @@ from typing import TYPE_CHECKING
 
 from django.conf import settings
 from django.contrib.postgres.fields import ArrayField
-from django.core.mail import EmailMessage as EmailMessage_, EmailMultiAlternatives
+from django.core.mail import EmailMessage as EmailMessage_
 from django.db import models
 from django.db.transaction import atomic
 from django.utils.module_loading import import_string
@@ -34,7 +34,7 @@ class EmailMessageManager(models.Manager):
             .update(status=EmailMessage.Statuses.new)
 
     @atomic
-    def choose_to_send(self, count: int) -> models.QuerySet:
+    def choose_to_send(self, count: int) -> models.QuerySet["EmailMessage"]:
         base_queryset = self.select_for_update().filter(
             status=EmailMessage.Statuses.new, send_time=now()
         )
@@ -64,6 +64,7 @@ class EmailMessage(models.Model):
         choices=Statuses.choices,
         default=Statuses.new
     )
+
     priority = models.PositiveSmallIntegerField(
         choices=Priorities.choices,
         default=Priorities.high
@@ -73,40 +74,16 @@ class EmailMessage(models.Model):
 
     plain_body = models.TextField(blank=True)
 
-    html_body = models.TextField(blank=True)
-
-    name = models.CharField(max_length=100)
-
-    retries_number = models.PositiveSmallIntegerField(default=0)
-
-    max_retries_number = models.PositiveSmallIntegerField(default=1)
-
-    retry_delay = models.PositiveIntegerField(default=900)
-
-    from_email = models.EmailField(blank=True)
-
     fail_silently = models.BooleanField(default=False)
 
-    reply_to = ArrayField(models.EmailField(blank=True), blank=True)
-
     to = ArrayField(models.EmailField(blank=True), blank=True)
 
-    cc = ArrayField(models.EmailField(blank=True), blank=True)
-
-    bcc = ArrayField(models.EmailField(blank=True), blank=True)
-
-    headers = models.JSONField(blank=True)
-
-    context = models.JSONField(blank=True)
-
-    created_at = models.DateTimeField(default=now)
-
     send_time = models.DateTimeField(default=now)
 
     objects = EmailMessageManager()
 
     class Meta:
-        ordering = ("priority", "created_at")
+        ordering = ("priority")
 
     # def get_django_email_message(self):
     #     kwargs = {
@@ -137,11 +114,13 @@ class EmailMessage(models.Model):
     #     return email_message
 
     def send(self) -> None:
+        print("sending email message")
         email_message = EmailMessage_(subject=self.subject, body=self.plain_body, to=self.to)
         email_message.send(self.fail_silently)
 
     def process_sent(self, need_to_delete: bool) -> None:
         if need_to_delete:
+            print("message sent.deleting.")
             self.delete()
             return
 
