@@ -1,5 +1,4 @@
 from queue import Empty
-from logging import getLogger
 from threading import Thread
 from typing import TYPE_CHECKING
 
@@ -9,9 +8,6 @@ if TYPE_CHECKING:
     from mail_office.queue_ import Queue
 
 
-logger = getLogger(__name__)
-
-
 class Postman(Thread):
     """
     Sender of queued messages (Worker).
@@ -52,7 +48,6 @@ class Postman(Thread):
         while not self.shutdown_event.is_set():
             try:
                 email_message: "EmailMessage" = self.queue.get(timeout=2)
-                logger.info("received email message")
             except Empty:
                 # It is perceived as the fact that no new messages have
                 # appeared in the queue at the time "get" is called.
@@ -64,7 +59,6 @@ class Postman(Thread):
         try:
             email_message.send()
             email_message.process_sent(self.delete_sent_messages)
-            logger.info("email sent")
         except Exception as exc:
-            logger.exception("lol", exc_info=exc)
+            print("send failed")
             email_message.process_failed(exc)
